@@ -2,7 +2,7 @@ package Finance::Nadex;
 
 use strict;
 use warnings;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use LWP::UserAgent;
 use JSON;
@@ -444,7 +444,7 @@ sub get_time_series {
         
         my @contracts;
         foreach my $contract ( @{ $instrument_list_ref->{'markets'} } ) {
-            push(@contracts, $contract); 
+            push(@contracts, Finance::Nadex::Contract::_new($contract)); 
         };
         return @contracts;
         
@@ -994,7 +994,9 @@ get_time_series( market => 'Forex (Binaries)', instrument => 'AUD/USD' )
                 instrument specified must be one of the instruments currently available for trading on the exchange
                 for the provided market; the list of valid instruments can be obtained via get_market_instruments()
 
-Returns a list in which each element is a string containing the name of a time series for the given market and instrument;
+In the case of the '5 Minute Binaries' and '20 Minute Binaries' markets, returns a list in which each element is
+a L<Finance::Nadex::Contract> representing each contract available in the series; for all other markets, returns
+a string containing the name of a time series for the given market and instrument;
 a time series designates the period during which the contract is available for trading including the expiration time
 
 =head2 login
